@@ -24,6 +24,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 
+import org.videolan.vlc.BitmapCache;
 import org.videolan.vlc.Media;
 import org.videolan.vlc.R;
 import org.videolan.vlc.Util;
@@ -31,6 +32,7 @@ import org.videolan.vlc.Util;
 import android.content.Context;
 import android.content.res.Resources;
 import android.graphics.Bitmap;
+import android.graphics.BitmapFactory;
 import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
@@ -168,6 +170,16 @@ public class AudioPlaylistAdapter extends BaseExpandableListAdapter {
         Resources res = mContext.getResources();
 
         Bitmap cover = AudioUtil.getCover(v.getContext(), list.get(0), 64);
+
+        if (cover == null) {
+            BitmapCache cache = BitmapCache.getInstance();
+            cover = cache.getBitmapFromMemCache(R.drawable.icon);
+            if (cover == null) {
+                cover = BitmapFactory.decodeResource(v.getResources(), R.drawable.icon);
+                cache.addBitmapToMemCache(R.drawable.icon, cover);
+            }
+        }
+
         holder.cover.setImageBitmap(cover);
 
         Util.setItemBackground(holder.layout, groupPosition);
@@ -209,6 +221,16 @@ public class AudioPlaylistAdapter extends BaseExpandableListAdapter {
         Resources res = mContext.getResources();
 
         Bitmap cover = AudioUtil.getCover(v.getContext(), list.get(0), 64);
+
+        if (cover == null) {
+            BitmapCache cache = BitmapCache.getInstance();
+            cover = cache.getBitmapFromMemCache(R.drawable.icon);
+            if (cover == null) {
+                cover = BitmapFactory.decodeResource(v.getResources(), R.drawable.icon);
+                cache.addBitmapToMemCache(R.drawable.icon, cover);
+            }
+        }
+
         holder.cover.setImageBitmap(cover);
 
         Util.setItemBackground(holder.layout, childPosition);
