@@ -26,6 +26,7 @@ import java.util.concurrent.BrokenBarrierException;
 import java.util.concurrent.CyclicBarrier;
 
 import org.videolan.android.ui.SherlockGridFragment;
+import org.videolan.vlc.AudioServiceController;
 import org.videolan.vlc.DatabaseManager;
 import org.videolan.vlc.Media;
 import org.videolan.vlc.MediaLibrary;
@@ -36,6 +37,7 @@ import org.videolan.vlc.VlcRunnable;
 import org.videolan.vlc.WeakHandler;
 import org.videolan.vlc.gui.CommonDialogs;
 import org.videolan.vlc.gui.PreferencesActivity;
+import org.videolan.vlc.gui.audio.AudioPlayerActivity;
 import org.videolan.vlc.interfaces.ISortable;
 
 import android.annotation.TargetApi;
@@ -94,9 +96,6 @@ public class VideoGridFragment extends SherlockGridFragment implements ISortable
     private ThumbnailerManager mThumbnailerManager;
     private VideoGridAnimator mAnimator;
 
-    // Play video from start or not
-    public boolean mFromStart = false;
-
     /* All subclasses of Fragment must include a public empty constructor. */
     public VideoGridFragment() { }
 
@@ -157,7 +156,6 @@ public class VideoGridFragment extends SherlockGridFragment implements ISortable
         mMediaLibrary.addUpdateHandler(mHandler);
         updateViewMode();
         mAnimator.animate();
-        mFromStart = false;
     }
 
     @Override
@@ -237,24 +235,32 @@ public class VideoGridFragment extends SherlockGridFragment implements ISortable
 
     @Override
     public void onGridItemClick(GridView l, View v, int position, long id) {
-        playVideo(position);
+        playVideo(position, false);
         super.onGridItemClick(l, v, position, id);
     }
 
-    protected void playVideo(int position) {
+    protected void playVideo(int position, boolean fromStart) {
         Media item = (Media) getListAdapter().getItem(position);
-        VideoPlayerActivity.start(getActivity(), item.getLocation(), mFromStart);
+        VideoPlayerActivity.start(getActivity(), item.getLocation(), fromStart);
+    }
+
+    protected void playAudio(int position) {
+        Media item = (Media) getListAdapter().getItem(position);
+        AudioServiceController.getInstance().load(item.getLocation(), 0, false, true);
+        AudioPlayerActivity.start(getActivity());
     }
 
     private boolean handleContextItemSelected(MenuItem menu, int position) {
         switch (menu.getItemId())
         {
         case R.id.video_list_play:
-            playVideo(position);
+            playVideo(position, false);
             return true;
         case R.id.video_list_play_from_start:
-            mFromStart = true;
-            playVideo(position);
+            playVideo(position, true);
+            return true;
+        case R.id.video_list_play_audio:
+            playAudio(position);
             return true;
         case R.id.video_list_info:
             Intent intent = new Intent(getActivity(), MediaInfoActivity.class);
